==> ui-18.1.1.tgz: package/components/compose/Compose.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "react/jsx-runtime";
import React, { useMemo } from 'react';
import { getClassName } from '@react-devui/utils';
import { useGeneralContext } from '../../hooks';
import { registerComponentMate } from '../../utils';
import { useComponentConfig, usePrefixConfig } from '../root';
import { DComposeItem } from './ComposeItem';
export const DComposeContext = React.createContext(null);
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DCompose' });
export const DCompose = (props) => {
    const _a = useComponentConfig(COMPONENT_NAME, props), { children, dSize, dVertical = false, dDisabled = false } = _a, restProps = __rest(_a, ["children", "dSize", "dVertical", "dDisabled"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    const { gSize, gDisabled } = useGeneralContext();
    //#endregion
    const size = dSize !== null && dSize !== void 0 ? dSize : gSize;
    const disabled = dDisabled || gDisabled;
    const contextValue = useMemo(() => ({
        gSize: size,
        gDisabled: disabled,
    }), [disabled, size]);
    return (_jsx(DComposeContext.Provider, Object.assign({ value: contextValue }, { children: _jsx("div", Object.assign({}, restProps, { className: getClassName(restProps.className, `${dPrefix}compose`, {
                [`${dPrefix}compose--vertical`]: dVertical,
            }), role: "group" }, { children: children })) })));
};
DCompose.Item = DComposeItem;

==> ui-18.4.1.tgz: package/components/compose/Compose.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "react/jsx-runtime";
import React, { useMemo } from 'react';
import { getClassName } from '@react-devui/utils';
import { useGeneralContext } from '../../hooks';
import { registerComponentMate } from '../../utils';
import { useComponentConfig, usePrefixConfig } from '../root';
import { DComposeItem } from './ComposeItem';
export const DComposeContext = React.createContext(null);
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DCompose' });
export const DCompose = (props) => {
    const _a = useComponentConfig(COMPONENT_NAME, props), { children, dSize, dVertical = false, dDisabled = false, __noStyle } = _a, restProps = __rest(_a, ["children", "dSize", "dVertical", "dDisabled", "__noStyle"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    const { gSize, gDisabled } = useGeneralContext();
    //#endregion
    const size = dSize !== null && dSize !== void 0 ? dSize : gSize;
    const disabled = dDisabled || gDisabled;
    const contextValue = useMemo(() => ({
        gSize: size,
        gDisabled: disabled,
    }), [disabled, size]);
    return (_jsx(DComposeContext.Provider, Object.assign({ value: contextValue }, { children: _jsx("div", Object.assign({}, restProps, { className: __noStyle
                ? restProps.className
                : getClassName(restProps.className, `${dPrefix}compose`, {
                    [`${dPrefix}compose--vertical`]: dVertical,
                }), role: "group" }, { children: children })) })));
};
DCompose.Item = DComposeItem;
